summaryrefslogtreecommitdiffstats
path: root/server
diff options
context:
space:
mode:
authorArtur Signell <artur@vaadin.com>2012-11-23 20:17:54 +0200
committerArtur Signell <artur@vaadin.com>2012-11-23 20:17:54 +0200
commita8f8fe7c1d87b61cbf74d2c04fcead5b55793e07 (patch)
treec22f6e7aa6d96c78acd4936b3574ab55beff229d /server
parentd553c3eca98e574d8d6a0b1f2a0276093f53b55e (diff)
downloadvaadin-framework-a8f8fe7c1d87b61cbf74d2c04fcead5b55793e07.tar.gz
vaadin-framework-a8f8fe7c1d87b61cbf74d2c04fcead5b55793e07.zip
Fixed javadoc referring to wrong class
Change-Id: Ie79a600aad9c5bff68d927011679fd15bdf51e4b
Diffstat (limited to 'server')
-rw-r--r--server/src/com/vaadin/server/AbstractClientConnector.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/server/src/com/vaadin/server/AbstractClientConnector.java b/server/src/com/vaadin/server/AbstractClientConnector.java
index cce73d0fa6..cb46756301 100644
--- a/server/src/com/vaadin/server/AbstractClientConnector.java
+++ b/server/src/com/vaadin/server/AbstractClientConnector.java
@@ -35,7 +35,6 @@ import java.util.logging.Logger;
import org.json.JSONException;
import org.json.JSONObject;
-import com.vaadin.client.ui.LegacyConnector;
import com.vaadin.event.EventRouter;
import com.vaadin.event.MethodEventSource;
import com.vaadin.shared.communication.ClientRpc;
@@ -44,6 +43,7 @@ import com.vaadin.shared.communication.SharedState;
import com.vaadin.shared.ui.ComponentStateUtil;
import com.vaadin.ui.Component.Event;
import com.vaadin.ui.HasComponents;
+import com.vaadin.ui.LegacyComponent;
import com.vaadin.ui.UI;
/**
@@ -122,7 +122,7 @@ public abstract class AbstractClientConnector implements ClientConnector,
* typically do not need to call {@link #markAsDirty()} as
* {@link #getState()} will mark the connector dirty and the
* framework will then check what, if anything, needs to be sent
* to the client. {@link LegacyConnector}s which rely on paint
* might still need to call this or {@link #markAsDirty()} .
*/
@Deprecated
@@ -122,7 +122,7 @@ public abstract class AbstractClientConnector implements ClientConnector,
* {@link #getState()} will mark the connector dirty and the
* framework will then check what, if anything, needs to be sent
- * to the client. {@link LegacyConnector}s which rely on paint
+ * to the client. {@link LegacyComponent}s which rely on paint
* might still need to call this or {@link #markAsDirty()} .
*/